Resolution class

Specifies in what resolution the application should be run.

Constructors

Resolution(double width, double height)
const
Resolution.fromJson(Map<String, dynamic> json)
Creates Resolution object from json
factory
Resolution.fromSize(String screenResolution)
Creates Resolution object from String in format
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
height → double
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
width → double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited