System class abstract

Constructors

System()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

isAndroid → bool
Whether the operating system is a version of Android.
final
isDesktop → bool
Whether the platform is native desktop
final
isIOS → bool
Whether the operating system is a version of iOS.
final
isLinux → bool
Whether the operating system is a version of Linux.
no setter
isMacOS → bool
Whether the operating system is a version of macOS. To override this property use macOsOverride.
no setter
isMobile → bool
Whether the platform is native mobile
final
isWindows → bool
Whether the operating system is a version of Microsoft Windows. To override this property use windowsOverride.
no setter

Constants

isWeb → const bool
Whether the platform is Web